﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win;
using System.Diagnostics;
using System.Reflection;
using System.IO;

namespace MemDataTable_CS
{
    public partial class Form1 : Form
    {
        private DataTable dt1;
        private CheckBox myCheckBox;

        public Form1()
        {
            InitializeComponent();

            this.ultraGrid1.BeforeSummaryDialog += UltraGrid1_BeforeSummaryDialog;
            this.ultraGrid1.AfterSummaryDialog += UltraGrid1_AfterSummaryDialog;
        }        

        private void UltraGrid1_BeforeSummaryDialog(object sender, BeforeSummaryDialogEventArgs e)
        {
            // Find the controls we need on the existing dialog. 
            Control summaryControl = e.SummaryDialog.Controls["SummaryControl"];
            Control backgroundPanel = summaryControl.Controls["ultraBackgroundPanel"];
            Control cancelUltraButton = backgroundPanel.Controls["cancelUltraButton"];
            Control okUltraButton = backgroundPanel.Controls["okUltraButton"];
            Control panelCheckboxes = backgroundPanel.Controls["panelCheckboxes"];
            Control sumCheckBox = panelCheckboxes.Controls["sumCheckBox"];

            // I am assuming that the application allows multiple summaries, so 
            // the dialog is using CheckBoxes. For a single summary, it would use radio buttons
            // and you would need to use these two controls and change the code below to add
            // a RadioButton insetad of a CheckBox. 
            //
            //Control panelRadios = backgroundPanel.Controls["panelRadios"];
            //Control sumRadio = panelRadios.Controls["sumRadio"];
                        
            this.myCheckBox = new CheckBox();
            this.myCheckBox.Name = "myCheckBox";
            this.myCheckBox.Text = "My custom summary type";
            this.myCheckBox.SetBounds(
                sumCheckBox.Left,
                sumCheckBox.Bottom + 4,
                sumCheckBox.Width,
                sumCheckBox.Height
                );

            if (DoesCustomSummaryAlreadyExist(e.Column))
                this.myCheckBox.Checked = true;

            // You will proabably want to add an image to the CheckBox here so it will look 
            // consistent with the other checkboxes. 
            //this.myCheckBox.Image = myImage;


            // The dialog and the controls need to be shifted and resized to accomodate
            // the new control. 
            int heightAdjustment = this.myCheckBox.Height + 4;
            panelCheckboxes.Height += heightAdjustment;
            e.SummaryDialog.Height += heightAdjustment;
            okUltraButton.Top += heightAdjustment;
            cancelUltraButton.Top += heightAdjustment;

            panelCheckboxes.Controls.Add(myCheckBox);
        }

        private void UltraGrid1_AfterSummaryDialog(object sender, AfterSummaryDialogEventArgs e)
        { 
            if (null != this.myCheckBox)
            {
                string myCustomSummaryKey = GetMyCustomSummaryKey(e.Column);
                bool customSummaryAlreadyExists = DoesCustomSummaryAlreadyExist(e.Column);
                if (this.myCheckBox.Checked && !customSummaryAlreadyExists)
                {
                    // I used a Formula summary here as a placeholder so I didn't have to 
                    // create an ICustomSummaryCalculator. But you would use SummaryType.Custom
                    // and use an overload of Summaries.Add that takes an ICustomSummaryCalculator.
                    e.Column.Band.Summaries.Add(myCustomSummaryKey, SummaryType.Formula, e.Column);
                }
                else if (!this.myCheckBox.Checked && customSummaryAlreadyExists)
                {
                    var ss = e.Column.Band.Summaries[myCustomSummaryKey];
                    e.Column.Band.Summaries.Remove(ss);
                }

                this.myCheckBox.Dispose();
                this.myCheckBox = null;
            }
        }

        private bool DoesCustomSummaryAlreadyExist(UltraGridColumn column)
        {
            string myCustomSummaryKey = GetMyCustomSummaryKey(column);
            return column.Band.Summaries.Exists(myCustomSummaryKey);
        }

        private string GetMyCustomSummaryKey(UltraGridColumn column)
        {
            return string.Format("MyCustomSummaryColumn - {0}", column.Key);
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            // Set grid's DataSource
            dt1 = DummyDataCreator.GetData(10);

            dt1.TableName = "Band 0";

            foreach (DataRow row in dt1.Rows)
            {
                row["DateTime 1"] = ((DateTime)row["DateTime 1"]).Date;
            }

            dt1.AcceptChanges();
            this.ultraGrid1.DataSource = dt1;
            
        }

        private void ultraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            var layout = e.Layout;
            var band = layout.Bands[0];
            var ov = layout.Override;

            ov.AllowRowSummaries = AllowRowSummaries.BasedOnDataType;
        }
    }
}
